;; Generated package description from go-mode.el  -*- no-byte-compile: t -*-
(define-package "go-mode" "1.6.0" "Major mode for the Go programming language" '((emacs "26.1")) :commit "3273fcece5d9ab7edd4f15b2d6bce61f4e5a0666" :keywords '("languages" "go") :url "https://github.com/dominikh/go-mode.el")
